django-siteforms documentation
==============================
https://github.com/idlesign/django-siteforms



Description
-----------

*Django reusable app to simplify form construction*

For those who consider maintaining templates-based forms solutions for Django a burden.

Features:

* Full form rendering support, including prolog and submit button
* Subforms support (represent entire other form as a form field): JSON, Foreign Key, Many-to-Many
* Field groups
* Declarative attributes for elements
* Simplified declarative forms layout, allowing fields ordering
* Simple ways to make fields hidden, disabled, readonly
* Aria-friendly (Accessible Rich Internet Applications)
* Complex widgets (e.g. using values from multiple fields) support

Supported styling:

* No CSS
* Bootstrap 4


Requirements
------------

1. Python 3.6+
2. Django 2.2+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    advanced
    bs4
